import { ElMessage } from 'element-plus';
import { PostLogin, userBindingWechat } from '../api/ai/user';
import { SERVE_URL } from '../constants';
import { useLogin } from '../hooks/useLogin';
import { userInfoKey } from './request';
import { Local } from './storage';

const resolveWechatInfo = () => {
	const url = window.location.href;
	const hashParams = url.split('#')[1];
	if (!hashParams) return;

	const [path, queryString] = hashParams.split('?');
	if (!queryString) return;

	const params = new URLSearchParams(queryString);
	const wxcode = params.get('wxcode');
	const isLogin = params.get('isWxLogin');
	if (!wxcode) return;

	return { wxcode, isLogin };
};

export const checkWechatLogin = async (wxcode: string) => {
	const { handleAfterLogin } = useLogin();
	// const loadingInstance = ElLoadingService({
	// 	// text: '加载中...',
	// 	target: '.layout-parent',
	// });

	const res = await PostLogin(
		{
			weixin_code: wxcode,
		},
		{
			noAuth: true,
			handleFail: false,
		}
	);
	if (res?.json_ok) {
		handleAfterLogin(res);
		Local.remove('isWechatLogin');

		// 使用新地址替换当前页面,移除微信登录参数
		// const newUrl = window.location.href.split('?')[0];
		// window.history.replaceState({}, '', SERVE_URL);
		// window.location.href = SERVE_URL;

		// window.location.reload();
	} else {
		// isShowLogin.value = true;
		Local.set('isWechatLogin', true);

		Local.set('wechatLoginMsgInfo', {
			type: 'error',
			value: res?.json_msg ?? '登录失败，请检查是否已绑定微信',
		});

		// window.location.href = SERVE_URL;
	}
};

export const handleBindWechat = async (wxcode: string) => {
	const userInfo = Local.get(userInfoKey);

	const res = await userBindingWechat({
		weixin_code: wxcode,
		user_name: userInfo.name,
	});

	const reloadPage = () => {
		const url = window.location.href;
		const [baseUrl, hash] = url.split('#/');
		const [path, search] = hash.split('?');

		if (search) {
			const searchParams = new URLSearchParams(search);
			searchParams.delete('isWxLogin');
			searchParams.delete('wxcode');
			searchParams.delete('wxstate');

			const newSearch = searchParams.toString();
			const newUrl = `${baseUrl}#/${path}${newSearch ? '?' + newSearch : ''}`;
			window.history.replaceState({}, '', newUrl);
			window.location.reload();
		}
	};
	if (res?.json_ok) {
		ElMessage.success('绑定成功');
		const userInfo = Local.get(userInfoKey);
		Local.set(userInfoKey, {
			...userInfo,
			/** @description 随便设置一个值，表示已经绑定了 */
			weixin_openid: 'sdfdf',
			weixin_nickname: res.json_url,
		});
		setTimeout(() => {
			reloadPage();
		}, 700);
	} else {
		ElMessage.error(res?.json_msg ?? '绑定失败');
		setTimeout(() => {
			reloadPage();
		}, 2000);
	}
};
export const checkWxOperate = () => {
	const result = resolveWechatInfo();
	if (!result) return;

	if (result.isLogin === 'Y') {
		checkWechatLogin(result.wxcode);
	} else {
		handleBindWechat(result.wxcode);
	}
};
